<?php

function getElementValue($parent, $elemName, $default) {
	$elemList = $parent->getElementsByTagName($elemName);
	if ($elemList->length > 0) {
		return $elemList->item(0)->textContent;
	}
	return $default;
}

function putElementValue($doc, $parent, $elemName, $value) {
	$elem = $doc->createElement($elemName, $value);
	$parent->appendChild($elem);
}

class Config {
	// PINsafe server
	public $server;

	// PINsafe port
	public $port;

	// PINsafe context
	public $context;

	// PINsafe agent secret
	public $secret;

	// SSL flag
	public $ssl;

	// Passwords flag;
	public $passwords;
	
	// Allow self-signed flag.
	public $ignoreCertErrors;
	
	// Cookie secret
	public $cookieSecret;
	
	// Cookie timeout (minutes)
	public $cookieTimeout;

	public function load($file) {
		$doc = new DOMDocument('1.0', 'UTF-8');
		$doc->load($file);
		$configElem = $doc->documentElement;
		$this->server = getElementValue($configElem, 'server', 'localhost');
		$this->port = getElementValue($configElem, 'port', '8080');
		$this->context = getElementValue($configElem, 'context', 'pinsafe');
		$this->secret = getElementValue($configElem, 'secret', 'secret');
		$this->ssl = getElementValue($configElem, 'secure', false);
		$this->passwords = getElementValue($configElem, 'passwords', true);
		$this->ignoreCertErrors = getElementValue($configElem, 'ignoreCertErrors', false);
		$this->cookieSecret = getElementValue($configElem, 'cookieSecret', '');
		$this->cookieTimeout = getElementValue($configElem, 'cookieTimeout', 10);
	}

	public function save($file) {
		$doc = new DOMDocument('1.0', 'UTF-8');
		$doc->formatOutput = true;
		$configElem = $doc->createElement('config');
		$doc->appendChild($configElem);
		putElementValue($doc, $configElem, 'server', $this->server);
		putElementValue($doc, $configElem, 'port', $this->port);
		putElementValue($doc, $configElem, 'context', $this->context);
		putElementValue($doc, $configElem, 'secret', $this->secret);
		putElementValue($doc, $configElem, 'secure', $this->ssl);
		putElementValue($doc, $configElem, 'passwords', $this->passwords);
		putElementValue($doc, $configElem, 'ignoreCertErrors', $this->ignoreCertErrors);
		putElementValue($doc, $configElem, 'cookieSecret', $this->cookieSecret);
		putElementValue($doc, $configElem, 'cookieTimeout', $this->cookieTimeout);
		$doc->save($file);
	}
}

?>
